Coefficient function for regDIF function
# S3 method for regDIF
coef(object, tau = NULL, method = "bic", ...)NULL
Fitted regDIF model object.
Optional character or numeric indicating the tau(s) at
which the model coefficients are returned. For character value, may be
"tau.min", which returns model coefficients for the value of tau
at which the minimum fit statistic is identified. For numeric, the value(s)
provided corresponds to the value(s) of tau.
Character value indicating the model fit statistic to be used
for determining "tau.min". Default is "bic". May also be
"aic".
Additional arguments to be passed through to coef.