Partial derivatives for binary items by item-blocks.
d_bernoulli_itemblock(
p_item,
etable,
theta,
pred_data,
item_data_current,
samp_size,
num_items,
num_predictors,
num_quad
)a "list" of first and second partial derivatives for Bernoulli item likelihood (to
use with multivariate Newton-Raphson)
Vector of item parameters.
E-table for item.
Matrix of adaptive theta values.
Matrix or dataframe of DIF and/or impact predictors.
Vector of current item responses.
Sample size in dataset.
Number of items in dataset.
Number of predictors in dataset.
Number of quadrature points used for approximating the latent variable.