Partial derivatives for ordinal items.
d_categorical(
parm,
p_item,
etable_item,
theta,
pred_data,
thr,
cov,
samp_size,
num_responses_item,
num_items,
num_quad
)a "list" of first and second partial derivatives for categorical item likelihood
(to use with coordinate descent and univariate Newton-Raphson)
Item parameter being maximized.
Vector of item parameters.
E-table for impact.
Matrix of adaptive theta values.
Matrix or dataframe of DIF and/or impact predictors.
Threshold value being maximized.
Covariate being maximized.
Sample size in dataset.
Number of responses for item.
Number of items in dataset.
Number of quadrature points used for approximating the latent variable.