Partial derivatives for continuous items.
d_gaussian_itemblock(
p_item,
etable,
theta,
responses_item,
pred_data,
samp_size,
num_items,
num_quad,
num_predictors
)a "list" of first and second partial derivatives for mean value of Gaussian item
likelihood (to use with coordinate descent and univariate Newton-Raphson)
Vector of item parameters.
E-table.
Matrix of adaptive theta values.
Vector of item responses.
Matrix or dataframe of DIF and/or impact predictors.
Sample size in dataset.
Number of items in dataset.
Number of quadrature points used for approximating the latent variable.
Number of predictors in dataset.