Maximization step.
information_criteria(
eout,
p,
item_data,
pred_data,
prox_data,
mean_predictors,
var_predictors,
item_type,
gamma,
samp_size,
num_responses,
num_items,
num_quad
)a "list" of information criteria to use for model selection
E-table output.
List of parameters.
Matrix or data.frame of item responses.
Matrix or data.frame of DIF and/or impact predictors.
Vector of observed proxy scores.
Possibly different matrix of predictors for the mean impact equation.
Possibly different matrix of predictors for the variance impact equation.
Optional character value or vector indicating the type of item to be modeled.
Numeric value indicating the gamma parameter in the MCP function.
Sample size in data set.
Number of responses for each item.
Number of items in data set.
Number of quadrature points used for approximating the latent variable.