Obtain standard errors for regDIF model(s).
se.regDIF(fit,
se.type = "sem",
tau = NULL,
...)Function returns an object of class se.regDIF
A regDIF fitted model object of class regDIF.
Upon designating fit, the default is to obtain standard errors
for the best-fitting model according to the minimum BIC model.
Character value indicating the method of computing standard errors for a regDIF fitted model. Default is "sem", or the supplemental EM algorithm (see Cai, 2008). Other options are in development and not yet supported.
Optional numeric or vector of tau values corresponding to those
already fit in fit.
Additional arguments to pass to regDIF function if different settings are desired.